﻿using ModuleTools.Attributes;
using ModuleTools.Enums;
using ModuleTools.ViewModels;
using System;

namespace DepartmentBusinessLogic.ViewModels
{
    /// <summary>
    /// Список связей сотрудников и должностей
    /// </summary>
    public class EmployeeEmployeePostListViewModel : ListViewModel<EmployeeEmployeePostViewModel> { }

    /// <summary>
    /// Связь сотрудника и должности
    /// </summary>
	[ViewModelControlElementClass()]
    public class EmployeeEmployeePostViewModel : ElementViewModel
    {
        [MapConfiguration("EmployeeId", AllowCopyWithoutRigth = false)]
		[ViewModelControlElementProperty("Сотрудник", ControlType.ControlGuid, MustHaveValue = true, ReadOnly = false, ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlEmployeeList, DepartmentWindowsDesktop")]
		public Guid EmployeeId { get; set; }

        [ViewModelControlListProperty("Сотрудник")]
        [MapConfiguration("Employee.LastName", IsDifficle = true)]
        public string EmployeeName { get; set; }

        [MapConfiguration("EmployeePostId")]
        [ViewModelControlElementProperty("Должность", ControlType.ControlGuid, MustHaveValue = true, ReadOnly = false, ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlEmployeePostList, DepartmentWindowsDesktop")]
        public Guid EmployeePostId { get; set; }

        [ViewModelControlListProperty("Должность")]
        [MapConfiguration("EmployeePost.EmployeePostName", IsDifficle = true)]
        public string EmployeePostName { get; set; }

        [ViewModelControlListProperty("Ставка", ColumnWidth = 80, DefaultCellStyleFormat = "N1")]
        [ViewModelControlElementProperty("Ставка", ControlType.ControlDecimal, DecimalPlaces = 1, MustHaveValue = true)]
        [MapConfiguration("Rate")]
        public decimal Rate { get; set; }

        [ViewModelControlElementProperty("Внутр. совм.", ControlType.ControlBool, MustHaveValue = true)]
        [MapConfiguration("IsInternalCombination")]
        public bool IsInternalCombination { get; set; }

        [ViewModelControlListProperty("Внутр. совм.", ColumnWidth = 80)]
        public string InternalCombination => IsInternalCombination ? "Да" : "Нет";

        [ViewModelControlElementProperty("Внеш. совм.", ControlType.ControlBool, MustHaveValue = true)]
        [MapConfiguration("IsExternalCombination")]
        public bool IsExternalCombination { get; set; }

        [ViewModelControlListProperty("Внеш. совм.", ColumnWidth = 80)]
        public string ExternalCombination => IsExternalCombination ? "Да" : "Нет";

        public override string ToString() => $"{EmployeeName}-{EmployeePostName}";
    }
}